@@ -45,6 +45,9 @@ class Model(object):
                 setattr(self, prop_name, value)
     
     def save(self):
+        for name, key in self._presave_sync_properties:
+            if key in self._cached_data:
+                setattr(self, name, self._cached_data[key])
         if self.key is None:
             self.key = unicode(self.db.uid())
         self.db[self.key] = self._raw_data
@@ -106,7 +109,19 @@ class Model(object):
                     raise Error('multiply key "%s" in model "%s"' % (prop.key, cls.__name__))
                 ret[k] = prop.key
         return ret
-        
+
+    @class_cached_property
+    def _presave_sync_properties(cls):
+        '''
+        {prop_attr_name: save_key_name}
+        '''
+        ret = []
+        for name, key in cls._properties.iteritems():
+            prop = cls.__dict__[name]
+            if prop.PRESAVE_SYNC:
+                ret.append((name, key))
+        return ret
+
     def __unicode__(self):
         items = []
         for k in ['key'] + self._properties.keys():
